#
# spec file for package libarchive (Version 1.3.1)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

Name:           libarchive2
Version:        2.8.4
Release:        4.1
Summary:        Library to create and read several different Streaming Archive Formats
URL:            http://code.google.com/p/libarchive/
# http://libarchive.googlecode.com/files/libarchive-%{version}.tar.gz
Source:         libarchive-%{version}.tar.bz2
License:        BSD License (revised)
Group:          Development/Libraries/C and C++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig expat bzip2 libacl-devel zlib-devel openssl-devel e2fsprogs-devel expat-devel
%if 0%{?suse_version} > 1020
BuildRequires:  libbz2-devel libexpat-devel
%endif
BuildRequires:  xz-devel

%description
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD
5 and 6.

The libarchive library offers a number of features that make it both
very flexible and very powerful.

- Automatic format detection: libarchive can automatically determine
  both the compression and the archive format, regardless of the
  data source. Most tar implementations do not automatically detect
  the compression format, few implementation that can correctly do
  this when reading from stdin or a socket. (The tar program
  included with Gunnar Ritter's heirloom collection also does full
  automatic format detection.)

- Writes POSIX formats: libarchive writes POSIX-standard formats,
  including "ustar," "pax interchange format," and the POSIX "cpio"
  format.

- Supports pax interchange format: Pax interchange format (which,
  despite the name, is really an extended tar format) eliminates
  almost all limitations of historic tar formats and provides a
  standard method for incorporating vendor-specific extensions.
  libarchive exploits this extension mechanism to support ACLs and
  file flags, for example. (Joerg Schilling's star archiver is
  another open-source tar program that supports pax interchange
  format.)

- Reads popular formats: libarchive can read GNU tar, ustar, pax
  interchange format, cpio, and older tar variants. The internal
  architecture is easily extensible. The only requirement for
  support is that it be possible to read the format without seeking
  in the file. (For example, a format that includes a compressed
  size field before the data cannot be correctly written without
  seeking.)

- High-Level API: the libarchive API makes it fairly simple to build
  an archive from a list of filenames or to extract the entries
  from an archive. However, the API also provides extreme
  flexibility with regards to data sources. For example, there are
  generic hooks that allow you to write an archive to a socket or
  read data from an archive entry into a memory buffer.

- Extensible. The internal design uses generic interfaces for
  compression, archive format detection and decoding, and archive
  data I/O. It should be very easy to add new formats, new
  compression methods, or new ways of reading/writing archives.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%debug_package

%package -n libarchive-devel
Requires:       %{name} == %{version}-%{release}
Requires:       glibc-devel
Requires:		pkgconfig
Group:          Development/Libraries/C and C++
Summary:        Development files for libarchive

%description -n libarchive-devel
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

This package contains the development files.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%package -n bsdtar
Group:          Productivity/Archiving/Compression
Summary:        Create and Read several different Streaming Archive Formats
Requires:       %{name} == %{version}-%{release}

%description -n bsdtar
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

This package contains the bsdtar cmdline utility.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%package -n bsdcpio
Group:          Productivity/Archiving/Compression
Summary:        BSD cpio Implementation
Requires:       %{name} == %{version}-%{release}

%description -n bsdcpio
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

This package contains the bsdcpio cmdline utility.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%prep
%setup -q -n "libarchive-%{version}"

%build
%configure --disable-static --with-pic
%__make %{?jobs:-j%{jobs}}

#check
#__make check

%install
%makeinstall
%__rm "%{buildroot}%{_mandir}/man5/"{tar,cpio,mtree}.5*
grep -r include %{buildroot}%{_includedir}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%clean
%__rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%doc COPYING INSTALL NEWS README
%{_libdir}/libarchive.so.2
%{_libdir}/libarchive.so.2.*.*

%files -n libarchive-devel
%defattr(-,root,root)
%exclude %{_libdir}/libarchive.la
%{_libdir}/libarchive.so
%{_includedir}/archive*
%doc %{_mandir}/man3/archive*.3*
%doc %{_mandir}/man3/libarchive*.3*
# better in the main package but that would create a file
# conflict with other versions of the library and make it
# impossible to install different SONAME versions side
# by side on the same system:
%doc %{_mandir}/man5/libarchive-formats.5*
%{_libdir}/pkgconfig/libarchive.pc

%files -n bsdtar
%defattr(-,root,root)
%{_bindir}/bsdtar
%doc %{_mandir}/man1/bsdtar.1*

%files -n bsdcpio
%defattr(-,root,root)
%{_bindir}/bsdcpio
%doc %{_mandir}/man1/bsdcpio.1*

%changelog
* Mon Nov 15 2010 cristian.rodriguez@opensuse.org
- Update to 2.8.4
- remove static libraries
- exclude "la" files
* Fri May  1 2009 pascal.bleser@opensuse.org
- update to 2.7.0
- implemented shared library naming policy
- new subpackage: bsdcpio
- add baselibs.conf
* Sun Apr  8 2007 mrueckert@suse.de
- updated to 2.0.28
- removed all patches:
  included upstream
* Sat Mar 24 2007 mrueckert@suse.de
- require libbz2-devel on >= 10.3
* Tue Mar  6 2007 mrueckert@suse.de
- updated bsdtar-1.2.53_ext2_include.patch:
  the old fix was not complete and on newer glibc/kernel-headers it
  seems you need to include linux/fs.h explicitly
  new name: bsdtar-1.3.1_linux_fs_includes.patch
- build with -fno-strict-aliasing
* Fri Nov 10 2006 mrueckert@suse.de
- added SA-06-24_libarchive.patch:
  fix DOS in libarchive (CVE-2006-5680)
  http://security.freebsd.org/advisories/FreeBSD-SA-06:24.libarchive.asc
* Fri Sep 22 2006 mrueckert@suse.de
- update to version 1.3.1
* Thu Apr 27 2006 mrueckert@suse.de
- updated to 1.2.53:
  Upstream merged the source tarball.
  Splitted of a bsdtar package
* Mon Feb 27 2006 mrueckert@suse.de
- fixed building of debuginfo package
* Mon Feb 27 2006 mrueckert@suse.de
- libarchive 1.2.38
